@@ -65,6 +65,7 @@ void LanguageManager::generateLangList()
 	langList.insert("blo",      langPair("Anii",                QObject::tr( "Anii" )) );
 	langList.insert("bn",       langPair("Bengali",             QObject::tr( "Bengali" )) );
 	langList.insert("br",       langPair("Breton",              QObject::tr( "Breton" )) );
+	langList.insert("br_FR",    langPair("Breton",              QObject::tr( "Breton" )) );
 	langList.insert("ca",       langPair("Catalan",             QObject::tr( "Catalan" )) );
 	langList.insert("cs",       langPair("Czech",               QObject::tr( "Czech" )) );
 	langList.insert("cs_CZ",    langPair("Czech",               QObject::tr( "Czech" )) );
@@ -140,6 +141,7 @@ void LanguageManager::generateLangList()
 	langList.insert("sq",       langPair("Albanian",            QObject::tr( "Albanian" )) );
 	langList.insert("sr",       langPair("Serbian",             QObject::tr( "Serbian" )) );
 	langList.insert("sv",       langPair("Swedish",             QObject::tr( "Swedish" )) );
+	langList.insert("sv_SE",    langPair("Swedish",             QObject::tr( "Swedish" )) );
 	langList.insert("th",       langPair("Thai",                QObject::tr( "Thai" )) );
 	langList.insert("th_TH",    langPair("Thai",                QObject::tr( "Thai" )) );
 	langList.insert("tr",       langPair("Turkish",             QObject::tr( "Turkish" )) );
