@@ -621,7 +621,7 @@ void Scribus134Format::writePrintOptions(ScXmlStreamWriter & docu)
 	docu.writeAttribute("useColor", static_cast<int>(m_Doc->Print_Options.useColor));
 	docu.writeAttribute("mirrorH", static_cast<int>(m_Doc->Print_Options.mirrorH));
 	docu.writeAttribute("mirrorV", static_cast<int>(m_Doc->Print_Options.mirrorV));
-	docu.writeAttribute("useICC", static_cast<int>(m_Doc->Print_Options.useICC));
+	docu.writeAttribute("useICC", static_cast<int>(m_Doc->CMSSettings.CMSinUse)); // Not used anymore, only for backward compatibility
 	docu.writeAttribute("doGCR", static_cast<int>(m_Doc->Print_Options.doGCR));
 	docu.writeAttribute("doClip", static_cast<int>(m_Doc->Print_Options.doClip));
 	docu.writeAttribute("setDevParam", static_cast<int>(m_Doc->Print_Options.setDevParam));
@@ -710,6 +710,11 @@ void Scribus134Format::writePdfOptions(ScXmlStreamWriter & docu)
 	docu.writeAttribute("fitWindow", static_cast<int>(m_Doc->PDF_Options.fitWindow));
 	docu.writeAttribute("PageLayout", m_Doc->PDF_Options.PageLayout);
 	docu.writeAttribute("openAction", m_Doc->PDF_Options.openAction);
+	for (int pdoA = 0; pdoA < m_Doc->PDF_Options.FontList.count(); ++pdoA)
+	{
+		docu.writeEmptyElement("DocFonts");
+		docu.writeAttribute("Name", m_Doc->PDF_Options.FontList[pdoA]);
+	}
 	for (int pdoF = 0; pdoF < m_Doc->PDF_Options.EmbedList.count(); ++pdoF)
 	{
 		docu.writeEmptyElement("Fonts");
@@ -1286,83 +1291,87 @@ void Scribus134Format::SetItemProps(ScXmlStreamWriter& docu, PageItem* item, con
 	QString tmp, tmpy;
 	if (newFormat)
 		docu.writeAttribute("OwnPage", item->OwnPage);
-	docu.writeAttribute("PTYPE",item->realItemType());
-	docu.writeAttribute("XPOS",item->xPos());
-	docu.writeAttribute("YPOS",item->yPos());
-	docu.writeAttribute("WIDTH",item->width());
-	docu.writeAttribute("HEIGHT",item->height());
-	docu.writeAttribute("RADRECT",item->cornerRadius());
+	docu.writeAttribute("PTYPE", item->realItemType());
+	docu.writeAttribute("XPOS", item->xPos());
+	docu.writeAttribute("YPOS", item->yPos());
+	docu.writeAttribute("WIDTH", item->width());
+	docu.writeAttribute("HEIGHT", item->height());
+	docu.writeAttribute("RADRECT", item->cornerRadius());
 	docu.writeAttribute("FRTYPE", item->FrameType);
 	docu.writeAttribute("CLIPEDIT", item->ClipEdited ? 1 : 0);
-	docu.writeAttribute("PWIDTH",item->lineWidth());
-	docu.writeAttribute("PCOLOR",item->fillColor());
-	docu.writeAttribute("PCOLOR2",item->lineColor());
-	if (!item->itemText.defaultStyle().charStyle().isInhFillColor())
-		docu.writeAttribute("TXTFILL",item->itemText.defaultStyle().charStyle().fillColor());
-	if (!item->itemText.defaultStyle().charStyle().isInhStrokeColor())
-		docu.writeAttribute("TXTSTROKE",item->itemText.defaultStyle().charStyle().strokeColor());
-	if (!item->itemText.defaultStyle().charStyle().isInhStrokeShade())
-		docu.writeAttribute("TXTSTRSH",item->itemText.defaultStyle().charStyle().strokeShade());
-	if (!item->itemText.defaultStyle().charStyle().isInhFillShade())
-		docu.writeAttribute("TXTFILLSH",item->itemText.defaultStyle().charStyle().fillShade());
-	if (!item->itemText.defaultStyle().charStyle().isInhScaleH())
-		docu.writeAttribute("TXTSCALE",item->itemText.defaultStyle().charStyle().scaleH() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhScaleV())
-		docu.writeAttribute("TXTSCALEV",item->itemText.defaultStyle().charStyle().scaleV() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhBaselineOffset())
-		docu.writeAttribute("TXTBASE",item->itemText.defaultStyle().charStyle().baselineOffset() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhShadowXOffset())
-		docu.writeAttribute("TXTSHX",item->itemText.defaultStyle().charStyle().shadowXOffset() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhShadowYOffset())
-		docu.writeAttribute("TXTSHY",item->itemText.defaultStyle().charStyle().shadowYOffset() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhOutlineWidth())
-		docu.writeAttribute("TXTOUT",item->itemText.defaultStyle().charStyle().outlineWidth() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhUnderlineOffset())
-		docu.writeAttribute("TXTULP",item->itemText.defaultStyle().charStyle().underlineOffset() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhUnderlineWidth())
-		docu.writeAttribute("TXTULW",item->itemText.defaultStyle().charStyle().underlineWidth() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhStrikethruOffset())
-		docu.writeAttribute("TXTSTP",item->itemText.defaultStyle().charStyle().strikethruOffset() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhStrikethruWidth())
-		docu.writeAttribute("TXTSTW",item->itemText.defaultStyle().charStyle().strikethruWidth() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhTracking())
-		docu.writeAttribute("TXTKERN",item->itemText.defaultStyle().charStyle().tracking() / 10.0);
-	if (!item->itemText.defaultStyle().charStyle().isInhWordTracking())
-		docu.writeAttribute("wordTrack",item->itemText.defaultStyle().charStyle().wordTracking());
-	if (!item->itemText.defaultStyle().isInhMinWordTracking())
-		docu.writeAttribute("MinWordTrack", item->itemText.defaultStyle().minWordTracking());
-	if (!item->itemText.defaultStyle().isInhMinGlyphExtension())
-		docu.writeAttribute("MinGlyphShrink", item->itemText.defaultStyle().minGlyphExtension());
-	if (!item->itemText.defaultStyle().isInhMaxGlyphExtension())
-		docu.writeAttribute("MaxGlyphExtend", item->itemText.defaultStyle().maxGlyphExtension());
-	if (!item->itemText.defaultStyle().isInhOpticalMargins())
-		docu.writeAttribute("OpticalMargins", item->itemText.defaultStyle().opticalMargins());
-	if (!item->itemText.defaultStyle().isInhHyphenationMode())
-		docu.writeAttribute("HyphenationMode", item->itemText.defaultStyle().hyphenationMode());
-	if (!item->itemText.defaultStyle().isInhLeftMargin() )
-		docu.writeAttribute("leftMargin", item->itemText.defaultStyle().leftMargin());
-	if (!item->itemText.defaultStyle().isInhRightMargin())
-		docu.writeAttribute("rightMargin", item->itemText.defaultStyle().rightMargin());
-	if (!item->itemText.defaultStyle().isInhFirstIndent())
-		docu.writeAttribute("firstIndent", item->itemText.defaultStyle().firstIndent());
+	docu.writeAttribute("PWIDTH", item->lineWidth());
+	docu.writeAttribute("PCOLOR", item->fillColor());
+	docu.writeAttribute("PCOLOR2", item->lineColor());
+
+	const ParagraphStyle& paraStyle(item->itemText.defaultStyle());
+	if (!paraStyle.charStyle().isInhFillColor())
+		docu.writeAttribute("TXTFILL", paraStyle.charStyle().fillColor());
+	if (!paraStyle.charStyle().isInhStrokeColor())
+		docu.writeAttribute("TXTSTROKE", paraStyle.charStyle().strokeColor());
+	if (!paraStyle.charStyle().isInhStrokeShade())
+		docu.writeAttribute("TXTSTRSH", paraStyle.charStyle().strokeShade());
+	if (!paraStyle.charStyle().isInhFillShade())
+		docu.writeAttribute("TXTFILLSH", paraStyle.charStyle().fillShade());
+	if (!paraStyle.charStyle().isInhScaleH())
+		docu.writeAttribute("TXTSCALE", paraStyle.charStyle().scaleH() / 10.0);
+	if (!paraStyle.charStyle().isInhScaleV())
+		docu.writeAttribute("TXTSCALEV", paraStyle.charStyle().scaleV() / 10.0);
+	if (!paraStyle.charStyle().isInhBaselineOffset())
+		docu.writeAttribute("TXTBASE", paraStyle.charStyle().baselineOffset() / 10.0);
+	if (!paraStyle.charStyle().isInhShadowXOffset())
+		docu.writeAttribute("TXTSHX", paraStyle.charStyle().shadowXOffset() / 10.0);
+	if (!paraStyle.charStyle().isInhShadowYOffset())
+		docu.writeAttribute("TXTSHY", paraStyle.charStyle().shadowYOffset() / 10.0);
+	if (!paraStyle.charStyle().isInhOutlineWidth())
+		docu.writeAttribute("TXTOUT", paraStyle.charStyle().outlineWidth() / 10.0);
+	if (!paraStyle.charStyle().isInhUnderlineOffset())
+		docu.writeAttribute("TXTULP", paraStyle.charStyle().underlineOffset() / 10.0);
+	if (!paraStyle.charStyle().isInhUnderlineWidth())
+		docu.writeAttribute("TXTULW", paraStyle.charStyle().underlineWidth() / 10.0);
+	if (!paraStyle.charStyle().isInhStrikethruOffset())
+		docu.writeAttribute("TXTSTP", paraStyle.charStyle().strikethruOffset() / 10.0);
+	if (!paraStyle.charStyle().isInhStrikethruWidth())
+		docu.writeAttribute("TXTSTW", paraStyle.charStyle().strikethruWidth() / 10.0);
+	if (!paraStyle.charStyle().isInhFeatures())
+		docu.writeAttribute("TXTFEATURES", paraStyle.charStyle().features().join(" "));
+	if (!paraStyle.charStyle().isInhTracking())
+		docu.writeAttribute("TXTKERN", paraStyle.charStyle().tracking() / 10.0);
+	if (!paraStyle.charStyle().isInhWordTracking())
+		docu.writeAttribute("wordTrack", paraStyle.charStyle().wordTracking());
+	if (!paraStyle.isInhMinWordTracking())
+		docu.writeAttribute("MinWordTrack", paraStyle.minWordTracking());
+	if (!paraStyle.isInhMinGlyphExtension())
+		docu.writeAttribute("MinGlyphShrink", paraStyle.minGlyphExtension());
+	if (!paraStyle.isInhMaxGlyphExtension())
+		docu.writeAttribute("MaxGlyphExtend", paraStyle.maxGlyphExtension());
+	if (!paraStyle.isInhOpticalMargins())
+		docu.writeAttribute("OpticalMargins", paraStyle.opticalMargins());
+	if (!paraStyle.isInhHyphenationMode())
+		docu.writeAttribute("HyphenationMode", paraStyle.hyphenationMode());
+	if (!paraStyle.isInhLeftMargin() )
+		docu.writeAttribute("leftMargin", paraStyle.leftMargin());
+	if (!paraStyle.isInhRightMargin())
+		docu.writeAttribute("rightMargin", paraStyle.rightMargin());
+	if (!paraStyle.isInhFirstIndent())
+		docu.writeAttribute("firstIndent", paraStyle.firstIndent());
 	docu.writeAttribute("COLUMNS", item->columns());
 	docu.writeAttribute("COLGAP", item->columnGap());
-	docu.writeAttribute("NAMEDLST",item->NamedLStyle);
-	docu.writeAttribute("SHADE",item->fillShade());
-	docu.writeAttribute("SHADE2",item->lineShade());
-	docu.writeAttribute("GRTYP",item->GrType);
-	docu.writeAttribute("ROT",item->rotation());
-	docu.writeAttribute("PLINEART",item->PLineArt);
+	docu.writeAttribute("NAMEDLST", item->NamedLStyle);
+	docu.writeAttribute("SHADE", item->fillShade());
+	docu.writeAttribute("SHADE2", item->lineShade());
+	docu.writeAttribute("GRTYP", item->GrType);
+	docu.writeAttribute("ROT", item->rotation());
+	docu.writeAttribute("PLINEART", item->PLineArt);
 	docu.writeAttribute("PLINEEND", item->PLineEnd);
 	docu.writeAttribute("PLINEJOIN", item->PLineJoin);
-	if (!item->itemText.defaultStyle().isInhLineSpacing())
-		docu.writeAttribute("LINESP",item->itemText.defaultStyle().lineSpacing());
-	if (!item->itemText.defaultStyle().isInhLineSpacingMode())
-		docu.writeAttribute("LINESPMode", item->itemText.defaultStyle().lineSpacingMode());
-	docu.writeAttribute("LOCALSCX",item->imageXScale());
-	docu.writeAttribute("LOCALSCY",item->imageYScale());
-	docu.writeAttribute("LOCALX",item->imageXOffset());
-	docu.writeAttribute("LOCALY",item->imageYOffset());
+	if (!paraStyle.isInhLineSpacing())
+		docu.writeAttribute("LINESP", paraStyle.lineSpacing());
+	if (!paraStyle.isInhLineSpacingMode())
+		docu.writeAttribute("LINESPMode", paraStyle.lineSpacingMode());
+	docu.writeAttribute("LOCALSCX", item->imageXScale());
+	docu.writeAttribute("LOCALSCY", item->imageYScale());
+	docu.writeAttribute("LOCALX", item->imageXOffset());
+	docu.writeAttribute("LOCALY", item->imageYOffset());
 	docu.writeAttribute("PICART", item->imageShown() ? 1 : 0);
 	docu.writeAttribute("PLTSHOW", item->PoShow ? 1 : 0);
 	docu.writeAttribute("BASEOF", item->BaseOffs);
@@ -1370,12 +1379,12 @@ void Scribus134Format::SetItemProps(ScXmlStreamWriter& docu, PageItem* item, con
 	docu.writeAttribute("textPathFlipped", static_cast<int>(item->textPathFlipped));
 	docu.writeAttribute("FLIPPEDH", item->imageFlippedH());
 	docu.writeAttribute("FLIPPEDV", item->imageFlippedV());
-/*	docu.writeAttribute("BBOXX",item->BBoxX);
-	docu.writeAttribute("BBOXH",item->BBoxH); */
-	if (!item->itemText.defaultStyle().charStyle().isInhFont())
-		docu.writeAttribute("IFONT",item->itemText.defaultStyle().charStyle().font().scName());
-	if (!item->itemText.defaultStyle().charStyle().isInhFontSize())
-		docu.writeAttribute("ISIZE",item->itemText.defaultStyle().charStyle().fontSize() / 10.0 );
+/*	docu.writeAttribute("BBOXX", item->BBoxX);
+	docu.writeAttribute("BBOXH", item->BBoxH); */
+	if (!paraStyle.charStyle().isInhFont())
+		docu.writeAttribute("IFONT", paraStyle.charStyle().font().scName());
+	if (!paraStyle.charStyle().isInhFontSize())
+		docu.writeAttribute("ISIZE", paraStyle.charStyle().fontSize() / 10.0 );
 	docu.writeAttribute("SCALETYPE", item->ScaleType ? 1 : 0);
 	docu.writeAttribute("RATIO", item->AspectRatio ? 1 : 0);
 	docu.writeAttribute("PRINTABLE", item->printEnabled() ? 1 : 0);
@@ -1430,11 +1439,11 @@ void Scribus134Format::SetItemProps(ScXmlStreamWriter& docu, PageItem* item, con
 	docu.writeAttribute("TEXTFLOW2", item->textFlowUsesBoundingBox() ? 1 : 0);
 	docu.writeAttribute("TEXTFLOW3", item->textFlowUsesContourLine() ? 1 : 0);
 	docu.writeAttribute("AUTOTEXT", item->isAutoText ? 1 : 0);
-	docu.writeAttribute("EXTRA",item->textToFrameDistLeft());
-	docu.writeAttribute("TEXTRA",item->textToFrameDistTop());
-	docu.writeAttribute("BEXTRA",item->textToFrameDistBottom());
-	docu.writeAttribute("REXTRA",item->textToFrameDistRight());
-	docu.writeAttribute("FLOP",item->firstLineOffset()); // here I think this FLOP "cher à mon cœur" is legitimate!
+	docu.writeAttribute("EXTRA", item->textToFrameDistLeft());
+	docu.writeAttribute("TEXTRA", item->textToFrameDistTop());
+	docu.writeAttribute("BEXTRA", item->textToFrameDistBottom());
+	docu.writeAttribute("REXTRA", item->textToFrameDistRight());
+	docu.writeAttribute("FLOP", item->firstLineOffset()); // here I think this FLOP "cher à mon cœur" is legitimate!
 	if (((item->asImageFrame() && !item->asLatexFrame()) || (item->asTextFrame())) && (!item->Pfile.isEmpty()))
 	{
 		if (item->isInlineImage)
@@ -1464,9 +1473,9 @@ void Scribus134Format::SetItemProps(ScXmlStreamWriter& docu, PageItem* item, con
 		docu.writeAttribute("PFILE3",Path2Relative(item->Pfile3, baseDir));
 	else
 		docu.writeAttribute("PFILE3","");
-	docu.writeAttribute("PRFILE",item->IProfile);
+	docu.writeAttribute("PRFILE", item->IProfile);
 	docu.writeAttribute("EPROF", item->EmProfile);
-	docu.writeAttribute("IRENDER",item->IRender);
+	docu.writeAttribute("IRENDER", item->IRender);
 	docu.writeAttribute("EMBEDDED", item->UseEmbedded ? 1 : 0);
 	docu.writeAttribute("LOCK", item->locked() ? 1 : 0);
 	docu.writeAttribute("LOCKR", item->sizeLocked() ? 1 : 0);
@@ -1513,7 +1522,7 @@ void Scribus134Format::SetItemProps(ScXmlStreamWriter& docu, PageItem* item, con
 		dlp += tmp.setNum((*dax)) + " ";
 	docu.writeAttribute("DASHS", dlp);
 	docu.writeAttribute("DASHOFF", item->DashOffset);
-	docu.writeAttribute("NUMPO",item->PoLine.size());
+	docu.writeAttribute("NUMPO", item->PoLine.size());
 	QString polp = "";
 	for (uint nxx=0; nxx<item->PoLine.size(); ++nxx)
 	{
@@ -1521,7 +1530,7 @@ void Scribus134Format::SetItemProps(ScXmlStreamWriter& docu, PageItem* item, con
 		polp += tmp.setNum(xf) + " " + tmpy.setNum(yf) + " ";
 	}
 	docu.writeAttribute("POCOOR", polp);
-	docu.writeAttribute("NUMCO",item->ContourLine.size());
+	docu.writeAttribute("NUMCO", item->ContourLine.size());
 	QString colp = "";
 	for (uint nxx=0; nxx<item->ContourLine.size(); ++nxx)
 	{
@@ -1535,7 +1544,7 @@ void Scribus134Format::SetItemProps(ScXmlStreamWriter& docu, PageItem* item, con
 	for (nx = item->Groups.begin(); nx != item->Groups.end(); ++nx)
 		glp += tmp.setNum((*nx)) + " ";
 	docu.writeAttribute("GROUPS", glp);
-	if (!item->itemText.defaultStyle().charStyle().isInhLanguage())
+	if (!paraStyle.charStyle().isInhLanguage())
 		docu.writeAttribute("LANGUAGE", item->itemText.defaultStyle().charStyle().language());
 	docu.writeAttribute("startArrowIndex", item->startArrowIndex());
 	docu.writeAttribute("endArrowIndex", item->endArrowIndex());
