@@ -272,7 +272,7 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 	bool ret = false;
 	SvgStyle *gc = new SvgStyle;
 	QDomElement docElem = inpdoc.documentElement();
-	QSize wh = parseWidthHeight(docElem);
+	QSizeF wh = parseWidthHeight(docElem);
 	double width = wh.width();
 	double height = wh.height();
 	if (!interactive || (flags & LoadSavePlugin::lfInsertPage))
@@ -319,7 +319,7 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 		if (points.size() > 3)
 		{
 			QMatrix matrix;
-			QSize wh2 = parseWidthHeight(docElem);
+			QSizeF wh2 = parseWidthHeight(docElem);
 			double w2 = wh2.width();
 			double h2 = wh2.height();
 			addGraphicContext();
@@ -501,7 +501,10 @@ void SVGPlug::addGraphicContext()
 {
 	SvgStyle *gc = new SvgStyle;
 	if ( m_gc.top() )
+	{
 		*gc = *( m_gc.top() );
+		gc->filter.clear(); // filter is not inheritable
+	}
 	m_gc.push( gc );
 }
 
@@ -673,6 +676,14 @@ void SVGPlug::finishNode( const QDomNode &e, PageItem* item)
 			}
 		}
 	}
+	if (!gc->filter.isEmpty())
+	{
+		if (filters.contains(gc->filter))
+		{
+			filterSpec filter = filters[gc->filter];
+			item->setFillBlendmode(filter.blendMode);
+		}
+	}
 }
 
 bool SVGPlug::isIgnorableNode( const QDomElement &e )
@@ -745,9 +756,9 @@ FPoint SVGPlug::parseTextPosition(const QDomElement &e, const FPoint* pos)
 	return FPoint(x, y);
 }
 
-QSize SVGPlug::parseWidthHeight(const QDomElement &e)
+QSizeF SVGPlug::parseWidthHeight(const QDomElement &e)
 {
-	QSize size(550, 841);
+	QSizeF size(550, 841);
 	QString sw = e.attribute("width", "100%");
 	QString sh = e.attribute("height", "100%");
 	double w =  550, h = 841;
@@ -757,7 +768,7 @@ QSize SVGPlug::parseWidthHeight(const QDomElement &e)
 		h = sh.endsWith("%") ? fromPercentage(sh) : parseUnit(sh);
 	if (!e.attribute("viewBox").isEmpty())
 	{
-		QRect viewBox = parseViewBox(e);
+		QRectF viewBox = parseViewBox(e);
 		double scw = (viewBox.width() > 0 && viewBox.height() > 0) ? viewBox.width()  : size.width();
 		double sch = (viewBox.width() > 0 && viewBox.height() > 0) ? viewBox.height() : size.height();
 		w *= (sw.endsWith("%") ? scw : 1.0);
@@ -775,14 +786,14 @@ QSize SVGPlug::parseWidthHeight(const QDomElement &e)
 		w = w / m * 842;
 		h = h / m * 842;
 	}
-	size.setWidth(qRound(w));
-	size.setHeight(qRound(h));
+	size.setWidth(w);
+	size.setHeight(h);
 	return size;
 }
 
-QRect SVGPlug::parseViewBox(const QDomElement &e)
+QRectF SVGPlug::parseViewBox(const QDomElement &e)
 {
-	QRect box(0, 0, 0, 0);
+	QRectF box(0, 0, 0, 0);
 	if ( !e.attribute( "viewBox" ).isEmpty() )
 	{
 		QString viewbox( e.attribute( "viewBox" ) );
@@ -824,6 +835,8 @@ void SVGPlug::parseDefs(const QDomElement &e)
 			parseClipPath(b);
 		else if (STag2 == "pattern")
 			parsePattern(b);
+		else if (STag2 == "filter")
+			parseFilter(b);
 		else if ( b.hasAttribute("id") )
 		{
 			QString id = b.attribute("id");
@@ -907,6 +920,28 @@ void SVGPlug::parseClipPathAttr(const QDomElement &e, FPointArray& clipPath)
 	}
 }
 
+void SVGPlug::parseFilterAttr(const QDomElement &e, PageItem* item)
+{
+	QString filterName;
+	if (e.hasAttribute("filter"))
+	{
+		QString attr = e.attribute("filter");
+		if (attr.startsWith( "url("))
+		{
+			unsigned int start = attr.indexOf("#") + 1;
+			unsigned int end = attr.lastIndexOf(")");
+			filterName = attr.mid(start, end - start);
+			if (filterName.isEmpty())
+				return;
+		}
+		if (filters.contains(filterName))
+		{
+			filterSpec spec = filters[filterName];
+			item->setFillBlendmode(spec.blendMode);
+		}
+	}
+}
+
 QList<PageItem*> SVGPlug::parseA(const QDomElement &e)
 {
 	QList<PageItem*> aElements;
@@ -957,6 +992,7 @@ QList<PageItem*> SVGPlug::parseGroup(const QDomElement &e)
 		if (gc->clipPath.size() != 0)
 			clipPath = gc->clipPath.copy();
 	}
+	parseFilterAttr(e, neu);
 	if (gElements.count() == 0 || (gElements.count() < 2 && (clipPath.size() == 0) && (gc->Opacity == 1.0)))
 	{
 		// Unfortunately we have to take the long route here, or we risk crash on undo/redo
@@ -1296,6 +1332,39 @@ QList<PageItem*> SVGPlug::parseLine(const QDomElement &e)
 	return LElements;
 }
 
+// The code of this function has been borrowed from Qt SVG module
+// and adapted for Scribus
+QVector<double> SVGPlug::parseNumbersList(const QString& numbersStr)
+{
+	QVector<double> numbers;
+	if (numbersStr.isEmpty())
+		return numbers;
+	numbers.reserve(8);
+
+	const QChar* str = numbersStr.data();
+
+	while (str->isSpace())
+		++str;
+	while (ScCLocale::isDigit(str->unicode()) ||
+	       *str == QLatin1Char('-') || *str == QLatin1Char('+') ||
+	       *str == QLatin1Char('.'))
+	{
+
+		numbers.append(ScCLocale::toDoubleC(str));
+
+		while (str->isSpace())
+			++str;
+		if (*str == QLatin1Char(','))
+			++str;
+
+		//eat the rest of space
+		while (str->isSpace())
+			++str;
+	}
+
+	return numbers;
+}
+
 QList<PageItem*> SVGPlug::parsePath(const QDomElement &e)
 {
 	FPointArray pArray;
@@ -1795,57 +1864,56 @@ QMatrix SVGPlug::parseTransform( const QString &transform )
 	QStringList subtransforms = trans.split(')', QString::SkipEmptyParts);
 	QStringList::ConstIterator it = subtransforms.begin();
 	QStringList::ConstIterator end = subtransforms.end();
-	for(; it != end; ++it)
+	for (; it != end; ++it)
 	{
 		QMatrix result;
 		QStringList subtransform = it->split('(', QString::SkipEmptyParts);
 		subtransform[0] = subtransform[0].trimmed().toLower();
 		subtransform[1] = subtransform[1].simplified();
-		QRegExp reg("[,( ]");
-		QStringList params = subtransform[1].split(reg, QString::SkipEmptyParts);
-		if(subtransform[0].startsWith(";") || subtransform[0].startsWith(","))
+		QVector<double> params = parseNumbersList(subtransform[1]);
+		if (subtransform[0].startsWith(";") || subtransform[0].startsWith(","))
 			subtransform[0] = subtransform[0].right(subtransform[0].length() - 1);
-		if(subtransform[0] == "rotate")
+		if (subtransform[0] == "rotate")
 		{
-			if(params.count() == 3)
+			if (params.count() == 3)
 			{
-				double x = ScCLocale::toDoubleC(params[1]);
-				double y = ScCLocale::toDoubleC(params[2]);
+				double x = params[1];
+				double y = params[2];
 				result.translate(x, y);
-				result.rotate(ScCLocale::toDoubleC(params[0]));
+				result.rotate(params[0]);
 				result.translate(-x, -y);
 			}
 			else
-				result.rotate(ScCLocale::toDoubleC(params[0]));
+				result.rotate(params[0]);
 		}
-		else if(subtransform[0] == "translate")
+		else if (subtransform[0] == "translate")
 		{
-			if(params.count() == 2)
-				result.translate(ScCLocale::toDoubleC(params[0]), ScCLocale::toDoubleC(params[1]));
+			if (params.count() == 2)
+				result.translate(params[0], params[1]);
 			else    // Spec : if only one param given, assume 2nd param to be 0
-				result.translate(ScCLocale::toDoubleC(params[0]), 0);
+				result.translate(params[0], 0);
 		}
-		else if(subtransform[0] == "scale")
+		else if (subtransform[0] == "scale")
 		{
-			if(params.count() == 2)
-				result.scale(ScCLocale::toDoubleC(params[0]), ScCLocale::toDoubleC(params[1]));
+			if (params.count() == 2)
+				result.scale(params[0], params[1]);
 			else    // Spec : if only one param given, assume uniform scaling
-				result.scale(ScCLocale::toDoubleC(params[0]), ScCLocale::toDoubleC(params[0]));
+				result.scale(params[0], params[0]);
 		}
-		else if(subtransform[0] == "skewx")
-			result.shear(tan(ScCLocale::toDoubleC(params[0]) * 0.01745329251994329576), 0.0F);
-		else if(subtransform[0] == "skewy")
-			result.shear(0.0F, tan(ScCLocale::toDoubleC(params[0]) * 0.01745329251994329576));
-		else if(subtransform[0] == "matrix")
+		else if (subtransform[0] == "skewx")
+			result.shear(tan(params[0] * 0.01745329251994329576), 0.0F);
+		else if (subtransform[0] == "skewy")
+			result.shear(0.0F, tan(params[0] * 0.01745329251994329576));
+		else if (subtransform[0] == "matrix")
 		{
-			if(params.count() >= 6)
+			if (params.count() >= 6)
 			{
-				double sx = ScCLocale::toDoubleC(params[0]);
-				double sy = ScCLocale::toDoubleC(params[3]);
-				double p1 = ScCLocale::toDoubleC(params[1]);
-				double p2 = ScCLocale::toDoubleC(params[2]);
-				double p4 = ScCLocale::toDoubleC(params[4]);
-				double p5 = ScCLocale::toDoubleC(params[5]);
+				double sx = params[0];
+				double sy = params[3];
+				double p1 = params[1];
+				double p2 = params[2];
+				double p4 = params[4];
+				double p5 = params[5];
 				result.setMatrix(sx, p1, p2, sy, p4, p5);
 			}
 		}
@@ -2296,6 +2364,15 @@ void SVGPlug::parsePA( SvgStyle *obj, const QString &command, const QString &par
 				obj->clipPath = it.value().copy();
 		}
 	}
+	else if (command == "filter")
+	{
+		if (params.startsWith( "url("))
+		{
+			unsigned int start = params.indexOf("#") + 1;
+			unsigned int end = params.lastIndexOf(")");
+			obj->filter = params.mid(start, end - start);
+		}
+	}
 	else if( !isIgnorableNodeName(command) )
 	{
 		if (!m_unsupportedFeatures.contains(command))
@@ -2359,6 +2436,8 @@ void SVGPlug::parseStyle( SvgStyle *obj, const QDomElement &e )
 		parsePA( obj, "text-anchor", e.attribute( "text-anchor" ) );
 	if( !e.attribute( "text-decoration" ).isEmpty() )
 		parsePA( obj, "text-decoration", e.attribute( "text-decoration" ) );
+	if( !e.attribute( "filter" ).isEmpty() )
+		parsePA( obj, "filter", e.attribute( "filter" ) );
 	QString style = e.attribute( "style" ).simplified();
 	QStringList substyles = style.split(';', QString::SkipEmptyParts);
 	for( QStringList::Iterator it = substyles.begin(); it != substyles.end(); ++it )
@@ -2431,6 +2510,40 @@ void SVGPlug::parseColorStops(GradientHelper *gradient, const QDomElement &e)
 		gradient->gradient.filterStops();
 }
 
+void SVGPlug::parseFilter(const QDomElement &b)
+{
+	QString id = b.attribute("id", "");
+	QString origName = id;
+	if (id.isEmpty())
+		return;
+
+	filterSpec fspec;
+	fspec.blendMode = 0;
+
+	QDomElement child = b.firstChildElement();
+	if (child.isNull() || (child.tagName() != "feBlend"))
+	{
+		filters.insert(id, fspec);
+		m_nodeMap.insert(origName, b);
+		return;
+	}
+
+	QString blendModeStr = child.attribute("mode");
+	if (blendModeStr == "normal")
+		fspec.blendMode = 0;
+	if (blendModeStr == "darken")
+		fspec.blendMode = 1;
+	if (blendModeStr == "lighten")
+		fspec.blendMode = 2;
+	if (blendModeStr == "multiply")
+		fspec.blendMode = 3;
+	if (blendModeStr == "screen")
+		fspec.blendMode = 4;
+
+	filters.insert(id, fspec);
+	m_nodeMap.insert(origName, b);
+}
+
 void SVGPlug::parsePattern(const QDomElement &b)
 {
 	GradientHelper gradhelper;
