@@ -113,7 +113,7 @@ public:
 	SvgStyle() :
 		Display(true),
 		CSpace(false),
-		CurCol("None"),
+		CurCol("Black"),
 		dashOffset(0),
 		FontFamily(""),
 		FontStyle("normal"),
@@ -279,6 +279,9 @@ public:
 		int blendMode;
 	};
 	QMap<QString, filterSpec> filters;
+
+protected:
+	QVector<double> parseNumbersList(const QString& numbersStr);
 };
 
 #endif
