@@ -159,6 +159,15 @@ void ScriptPlugin::deleteAboutData(const AboutData* about) const
 bool ScriptPlugin::initPlugin()
 {
 	QString cm;
+#if defined(Q_OS_WIN)
+	QString pyHome = qApp->applicationDirPath() + "/python";
+	if (QDir(pyHome).exists())
+	{
+		QString ph = QDir::toNativeSeparators(pyHome);
+		pythonHome = ph.toLocal8Bit();
+		Py_SetPythonHome(pythonHome.data());
+	}
+#endif
 	Py_Initialize();
 	if (PyUnicode_SetDefaultEncoding("utf-8"))
 	{
@@ -333,7 +342,7 @@ PyMethodDef scribus_methods[] = {
 	{const_cast<char*>("getFontSize"), scribus_getfontsize, METH_VARARGS, tr(scribus_getfontsize__doc__)},
 	{const_cast<char*>("getGuiLanguage"), (PyCFunction)scribus_getlanguage, METH_NOARGS, tr(scribus_getlanguage__doc__)},
 	{const_cast<char*>("getHGuides"), (PyCFunction)scribus_getHguides, METH_NOARGS, tr(scribus_getHguides__doc__)},
-	{const_cast<char*>("getImageFile"), scribus_getimgname, METH_VARARGS, tr(scribus_getimgname__doc__)},
+	{const_cast<char*>("getImageFile"), scribus_getimagefile, METH_VARARGS, tr(scribus_getimagefile__doc__)},
 	{const_cast<char*>("getImageScale"), scribus_getimgscale, METH_VARARGS, tr(scribus_getimgscale__doc__)},
 	{const_cast<char*>("getLayers"), (PyCFunction)scribus_getlayers, METH_NOARGS, tr(scribus_getlayers__doc__)},
 	{const_cast<char*>("getLayerBlendmode"), scribus_glayerblend, METH_VARARGS, tr(scribus_glayerblend__doc__)},
