@@ -359,8 +359,9 @@ void TabKeyboardShortcutsWidget::insertActions()
 	QTreeWidgetItem *currMenuLVI = NULL;
 	QTreeWidgetItem *prevLVI = NULL;
 	QTreeWidgetItem *prevMenuLVI = NULL;
-	for (QVector< QPair<QString, QStringList> >::Iterator itmenu = defMenus->begin(); itmenu != defMenus->end(); ++itmenu )
+	for (int i = 0; i < defMenus->count(); ++i)
 	{
+		const QPair<QString, QStringList> &actionStrings = defMenus->at(i);
 		if (firstMenu)
 		{
 			currMenuLVI = new QTreeWidgetItem(keyTable);
@@ -370,15 +371,24 @@ void TabKeyboardShortcutsWidget::insertActions()
 			currMenuLVI = new QTreeWidgetItem(keyTable, prevMenuLVI);
 		Q_CHECK_PTR(currMenuLVI);
 		lviToMenuMap.append(currMenuLVI);
-		currMenuLVI->setText(0, itmenu->first);
+		currMenuLVI->setText(0, actionStrings.first);
 		currMenuLVI->setExpanded(true);
 		currMenuLVI->setFlags(Qt::ItemIsEnabled);
 		prevMenuLVI=currMenuLVI;
 		first=true;
 		currLVI=0;
 		prevLVI=0;
-		for ( QStringList::Iterator it = itmenu->second.begin(); it != itmenu->second.end(); ++it )
+		for (int j = 0; j < actionStrings.second.count(); ++j)
 		{
+			QString actionName = actionStrings.second.at(j);
+			if (!keyMap.contains(actionName))
+			{
+				qDebug() << "The action " << actionName << " is not defined in shortcut map";
+				continue;
+			}
+			const Keys &actionKeys = keyMap[actionName];
+			if (actionKeys.cleanMenuText.isEmpty())
+				continue;
 			if (first)
 			{
 				currLVI = new QTreeWidgetItem(currMenuLVI);
@@ -387,15 +397,16 @@ void TabKeyboardShortcutsWidget::insertActions()
 			else
 				currLVI = new QTreeWidgetItem(currMenuLVI, prevLVI);
 			Q_CHECK_PTR(currLVI);
-			lviToActionMap.insert(currLVI, *it);
-			currLVI->setText(0, keyMap[*it].cleanMenuText);
-			currLVI->setText(1, keyMap[*it].keySequence);
-			prevLVI=currLVI;
+			lviToActionMap.insert(currLVI, actionName);
+			currLVI->setText(0, actionKeys.cleanMenuText);
+			currLVI->setText(1, actionKeys.keySequence);
+			prevLVI = currLVI;
 		}
 	}
 	//Non menu actions
-	for (QVector< QPair<QString, QStringList> >::Iterator itmenu = defNonMenuActions->begin(); itmenu != defNonMenuActions->end(); ++itmenu )
+	for (int i = 0; i < defNonMenuActions->count(); ++i)
 	{
+		const QPair<QString, QStringList> &actionStrings = defNonMenuActions->at(i);
 		if (firstMenu)
 		{
 			currMenuLVI = new QTreeWidgetItem(keyTable);
@@ -405,15 +416,24 @@ void TabKeyboardShortcutsWidget::insertActions()
 			currMenuLVI = new QTreeWidgetItem(keyTable, prevMenuLVI);
 		Q_CHECK_PTR(currMenuLVI);
 		lviToMenuMap.append(currMenuLVI);
-		currMenuLVI->setText(0, itmenu->first);
+		currMenuLVI->setText(0, actionStrings.first);
 		currMenuLVI->setExpanded(true);
 		currMenuLVI->setFlags(Qt::ItemIsEnabled);
 		prevMenuLVI=currMenuLVI;
 		first=true;
 		currLVI=0;
 		prevLVI=0;
-		for ( QStringList::Iterator it = itmenu->second.begin(); it != itmenu->second.end(); ++it )
+		for (int j = 0; j < actionStrings.second.count(); ++j)
 		{
+			QString actionName = actionStrings.second.at(j);
+			if (!keyMap.contains(actionName))
+			{
+				qDebug() << "The action " << actionName << " is not defined in shortcut map";
+				continue;
+			}
+			const Keys &actionKeys = keyMap[actionName];
+			if (actionKeys.cleanMenuText.isEmpty())
+				continue;
 			if (first)
 			{
 				currLVI=new QTreeWidgetItem(currMenuLVI);
@@ -422,9 +442,9 @@ void TabKeyboardShortcutsWidget::insertActions()
 			else
 				currLVI=new QTreeWidgetItem(currMenuLVI, prevLVI);
 			Q_CHECK_PTR(currLVI);
-			lviToActionMap.insert(currLVI, *it);
-			currLVI->setText(0, keyMap[*it].cleanMenuText);
-			currLVI->setText(1, keyMap[*it].keySequence);
+			lviToActionMap.insert(currLVI, actionName);
+			currLVI->setText(0, actionKeys.cleanMenuText);
+			currLVI->setText(1, actionKeys.keySequence);
 			prevLVI=currLVI;
 		}
 	}
@@ -454,9 +474,14 @@ void TabKeyboardShortcutsWidget::applySearch( const QString & newss )
 
 void TabKeyboardShortcutsWidget::dispKey(QTreeWidgetItem* qlvi, QTreeWidgetItem*)
 {
+	if (setKeyButton->isChecked())
+	{
+		releaseKeyboard();
+		setKeyButton->setChecked(false);
+	}
 	if (qlvi!=0 && lviToActionMap.contains(qlvi))
 	{
-		selectedLVI=qlvi;
+		selectedLVI = qlvi;
 		QString actionName=lviToActionMap[qlvi];
 		if (actionName.isEmpty())
 			return;
@@ -470,8 +495,12 @@ void TabKeyboardShortcutsWidget::dispKey(QTreeWidgetItem* qlvi, QTreeWidgetItem*
 	{
 		noKey->setChecked(true);
 		keyDisplay->setText("");
-		selectedLVI=0;
+		selectedLVI = 0;
 	}
+	noKey->setEnabled(selectedLVI != 0);
+	userDef->setEnabled(selectedLVI != 0);
+	setKeyButton->setEnabled(selectedLVI != 0);
+	keyDisplay->setEnabled(selectedLVI != 0);
 }
 
 bool TabKeyboardShortcutsWidget::event( QEvent* ev )
@@ -522,20 +551,24 @@ void TabKeyboardShortcutsWidget::keyPressEvent(QKeyEvent *k)
 				keyCode |= k->key();
 				keyDisplay->setText(getKeyText(keyCode));
 				releaseKeyboard();
-				if (checkKey(keyCode))
+				if (selectedLVI)
 				{
-					QMessageBox::information(this, CommonStrings::trWarning,
-											tr("This key sequence is already in use"),
-											CommonStrings::tr_OK);
-					selectedLVI->setText(1,keyMap[lviToActionMap[selectedLVI]].keySequence);
-					keyDisplay->setText(keyMap[lviToActionMap[selectedLVI]].keySequence);
-				}
-				else
-				{
-					QKeySequence newKeySequence(keyCode);
-					selectedLVI->setText(1, QString(newKeySequence));
-					keyMap[lviToActionMap[selectedLVI]].keySequence=newKeySequence;
-					userDef->setChecked(true);
+					QString actionName = lviToActionMap[selectedLVI];
+					if (checkKey(keyCode))
+					{
+						QMessageBox::information(this, CommonStrings::trWarning,
+												tr("This key sequence is already in use"),
+												CommonStrings::tr_OK);
+						selectedLVI->setText(1,keyMap[actionName].keySequence);
+						keyDisplay->setText(keyMap[actionName].keySequence);
+					}
+					else
+					{
+						QKeySequence newKeySequence(keyCode);
+						selectedLVI->setText(1, QString(newKeySequence));
+						keyMap[actionName].keySequence = newKeySequence;
+						userDef->setChecked(true);
+					}
 				}
 				setKeyButton->setChecked(false);
 		}
